@@ -37,16 +37,18 @@
 #' @examples
 #' \donttest{
 #' bbox <- c(-83.751812,42.272984,-83.741255,42.279716)
-#' data <- streetscape::strview_searchByGeo(bbox = bbox,
-#'                                          epsg = 2253,
-#'                                          token = "token",
-#'                                          is_pano = TRUE)
-#' data <- streetscape::strview_searchByGeo(x = -83.741289,
-#'                                          y = 42.270146,
-#'                                          r = 100,
-#'                                          epsg = 2253,
-#'                                          token = "token",
-#'                                          is_pano = TRUE)
+#' if (isTRUE(file.exists("streetscape_token.sysdata"))) {
+#'  data <- streetscape::strview_searchByGeo(bbox = bbox,
+#'                                           epsg = 2253,
+#'                                           token = "",
+#'                                           is_pano = TRUE)
+#'  data <- streetscape::strview_searchByGeo(x = -83.741289,
+#'                                           y = 42.270146,
+#'                                           r = 100,
+#'                                           epsg = 2253,
+#'                                           token = "",
+#'                                           is_pano = TRUE)
+#' }
 #' }
 #'
 #' @export
@@ -58,9 +60,14 @@ strview_searchByGeo <- function(x,y,r,
                                 limit= 10,
                                 fields = c(),
                                 ...){
-  if (token == "") {
-    stop("access token is missing.")
+  # check token
+  if (token != "") {
+    token <- create_check_token(token, ifsave = FALSE)
+  } else if (token == "") {
+    token <- create_check_token(token, ifsave = TRUE)
   }
+
+  # check arguments
   if (missing(epsg)) {
     stop("epsg is missing. Please set epsg code")
   }
@@ -79,6 +86,7 @@ strview_searchByGeo <- function(x,y,r,
   suppressWarnings(
     longlat <- sp::CRS("+proj=longlat")
   )
+
   # create bbox
   if (missing(bbox)) {
     if (missing(x) || missing(y) || missing(r)) {
@@ -186,11 +194,13 @@ strview_searchByGeo <- function(x,y,r,
 #' @importFrom dplyr filter
 #' @examples
 #' \donttest{
-#' data <- streetscape::strview_search_nnb(
-#'         x = -83.743460634278,
-#'         y = 42.277848830294,
-#'         epsg = 2253,
-#'         token = 'token')
+#' if (isTRUE(file.exists("streetscape_token.sysdata"))) {
+#'  data <- streetscape::strview_search_nnb(
+#'          x = -83.743460634278,
+#'          y = 42.277848830294,
+#'          epsg = 2253,
+#'          token = '')
+#' }
 #' }
 #' @export
 #' @rdname strview_search
@@ -255,11 +265,13 @@ strview_search_nnb <- function(x,
 #' @examples
 #' \donttest{
 #' bbox <- c(-83.752041,42.274896,-83.740711,42.281945)
-#' data <- streetscape::strview_search_osm(
-#'         bbox = bbox,
-#'         epsg = 2253,
-#'         token = 'token',
-#'         size = 100)
+#' if (isTRUE(file.exists("streetscape_token.sysdata"))) {
+#'  data <- streetscape::strview_search_osm(
+#'          bbox = bbox,
+#'          epsg = 2253,
+#'          token = '',
+#'          size = 100)
+#' }
 #' }
 #' @importFrom sf st_transform as_Spatial
 #' @importFrom sf st_union st_sample st_coordinates
@@ -270,6 +282,13 @@ strview_search_osm <- function(bbox,
                                token,
                                fields = c(),
                                size, ...){
+  # check token
+  if (token != "") {
+    token <- create_check_token(token, ifsave = FALSE)
+  } else if (token == "") {
+    token <- create_check_token(token, ifsave = TRUE)
+  }
+
   if (missing(bbox)) {
     stop("please specify bbox")
   }
@@ -313,7 +332,7 @@ strview_search_osm <- function(bbox,
       df <- strview_search_nnb(x=coords[i,1],
                                y=coords[i,2],
                                epsg,
-                               token,
+                               token = token,
                                fields,
                                ...)
       if (!inherits(df, "numeric")) {
@@ -351,11 +370,14 @@ strview_search_osm <- function(bbox,
 #' x <- c(-83.752041, -83.740711)
 #' y <- c(42.274896, 42.281945)
 #' viewpoints <- cbind(x, y)
-#' data <- streetscape::strview_search_multi(
-#'         viewpoints = viewpoints,
-#'         epsg = 2253,
-#'         token = 'token')
+#' if (isTRUE(file.exists("streetscape_token.sysdata"))) {
+#'  data <- streetscape::strview_search_multi(
+#'          viewpoints = viewpoints,
+#'          epsg = 2253,
+#'          token = '')
 #' }
+#' }
+#'
 #' @export
 #' @rdname strview_search
 #'
@@ -364,6 +386,13 @@ strview_search_multi <- function(viewpoints,
                                  token,
                                  fields = c(),
                                  ...) {
+  # check token
+  if (token != "") {
+    token <- create_check_token(token, ifsave = FALSE)
+  } else if (token == "") {
+    token <- create_check_token(token, ifsave = TRUE)
+  }
+
   if (missing(viewpoints)) {
     stop("viewpoints is missing!")
   }
@@ -380,7 +409,7 @@ strview_search_multi <- function(viewpoints,
     df <- strview_search_nnb(x=viewpoints[i,1],
                              y=viewpoints[i,2],
                              epsg,
-                             token,
+                             token = token,
                              fields,
                              ...)
     if (!inherits(df, "numeric")) {
